==> qmmp_1.0.5.orig.tar.bz2: qmmp-1.0.5/src/plugins/CommandLineOptions/StatusOption/translations/status_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>StatusOption</name>
    <message>
        <location filename="../statusoption.cpp" line="39"/>
        <source>Print playback status</source>
        <translation>Imprimir estado de reprodução</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="41"/>
        <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
        <translation>Imprimir nome de faixa formatado (exemplo: qmmp --nowplaying &quot;%t - %a&quot;)</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="42"/>
        <source>Print --nowplaying syntax</source>
        <translation>Imprimir sintaxe --nowplaying</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="89"/>
        <source>Syntax:</source>
        <translation>Sintaxe:</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="90"/>
        <source>%p - artist</source>
        <translation>%p - artista</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="91"/>
        <source>%a - album</source>
        <translation>%a - álbum</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="92"/>
        <source>%aa - album artist</source>
        <translation>%aa - artista do álbum</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="93"/>
        <source>%t - title</source>
        <translation>%t - título</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="94"/>
        <source>%n - track</source>
        <translation>%n - faixa</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="95"/>
        <source>%NN - 2-digit track</source>
        <translation>%NN - faixa com 2 dígitos</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="96"/>
        <source>%g - genre</source>
        <translation>%g - género</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="97"/>
        <source>%c - comment</source>
        <translation>%c - comentário</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="98"/>
        <source>%C - composer</source>
        <translation>%C - compositor</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="99"/>
        <source>%D - disc number</source>
        <translation>%D - número do disco</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="100"/>
        <source>%f - file name</source>
        <translation>%f - nome do ficheiro</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="101"/>
        <source>%F - full path</source>
        <translation>%F - caminho completo</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="102"/>
        <source>%y - year</source>
        <translation>%y - ano</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="103"/>
        <source>%l - duration</source>
        <translation>%l - duração</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="104"/>
        <source>%if(A&amp;B&amp;C,D,E) - condition</source>
        <translation>%if(A&amp;B&amp;C,D,E) - condição</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.6.orig.tar.bz2: qmmp-1.2.6/src/plugins/CommandLineOptions/StatusOption/translations/status_plugin_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt">
<context>
    <name>StatusOption</name>
    <message>
        <location filename="../statusoption.cpp" line="39"/>
        <source>Print playback status</source>
        <translation>Imprimir estado de reprodução</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="41"/>
        <source>Print formatted track name (example: qmmp --nowplaying &quot;%t - %a&quot;)</source>
        <translation>Imprimir nome de faixa formatado (exemplo: qmmp --nowplaying &quot;%t - %a&quot;)</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="42"/>
        <source>Print --nowplaying syntax</source>
        <translation>Imprimir sintaxe --nowplaying</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="87"/>
        <source>Syntax:</source>
        <translation>Sintaxe:</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="88"/>
        <source>%p - artist</source>
        <translation>%p - artista</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="89"/>
        <source>%a - album</source>
        <translation>%a - álbum</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="90"/>
        <source>%aa - album artist</source>
        <translation>%aa - artista do álbum</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="91"/>
        <source>%t - title</source>
        <translation>%t - título</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="92"/>
        <source>%n - track</source>
        <translation>%n - faixa</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="93"/>
        <source>%NN - 2-digit track</source>
        <translation>%NN - faixa com 2 dígitos</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="94"/>
        <source>%g - genre</source>
        <translation>%g - género</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="95"/>
        <source>%c - comment</source>
        <translation>%c - comentário</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="96"/>
        <source>%C - composer</source>
        <translation>%C - compositor</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="97"/>
        <source>%D - disc number</source>
        <translation>%D - número do disco</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="98"/>
        <source>%f - file name</source>
        <translation>%f - nome do ficheiro</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="99"/>
        <source>%F - full path</source>
        <translation>%F - caminho completo</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="100"/>
        <source>%y - year</source>
        <translation>%y - ano</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="101"/>
        <source>%l - duration</source>
        <translation>%l - duração</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="102"/>
        <source>%if(A&amp;B&amp;C,D,E) - condition</source>
        <translation>%if(A&amp;B&amp;C,D,E) - condição</translation>
    </message>
    <message>
        <location filename="../statusoption.cpp" line="103"/>
        <source>%dir(n) - directory name located on n levels above</source>
        <translation>%dir(n) - nome do diretório localizado em &apos;n&apos; níveis acima</translation>
    </message>
</context>
</TS>
